==> squid-1.0.10-src.tar.gz: squid-1.0.10/include/mime_table.h <==
#define EXT_TABLE_LEN 89
static ext_table_entry ext_mime_table[] =
{
    {"Z", "application/x-compressed", "x-compress", "binary"},
    {"ai", "application/postscript", "8bit", "text"},
    {"aif", "audio/x-aiff", "binary", "sound"},
    {"aifc", "audio/x-aiff", "binary", "sound"},
    {"aiff", "audio/x-aiff", "binary", "sound"},
    {"au", "audio/basic", "binary", "sound"},
    {"avi", "video/x-msvideo", "binary", "movie"},
    {"bcpio", "application/x-bcpio", "binary", "binary"},
    {"bin", "application/macbinary", "macbinary", "binary"},
    {"c", "text/plain", "7bit", "text"},
    {"cc", "text/plain", "7bit", "text"},
    {"cdf", "application/x-netcdf", "binary", "binary"},
    {"cpio", "application/x-cpio", "binary", "binary"},
    {"csh", "application/x-csh", "7bit", "text"},
    {"doc", "application/msword", "binary", "binary"},
    {"dvi", "application/x-dvi", "binary", "binary"},
    {"eps", "application/postscript", "8bit", "text"},
    {"etx", "text/x-setext", "7bit", "text"},
    {"exe", "application/octet-stream", "binary", "binary"},
    {"f90", "text/plain", "7bit", "text"},
    {"gif", "image/gif", "binary", "image"},
    {"gtar", "application/x-gtar", "binary", "binary"},
    {"gz", "text/plain", "x-gzip", "binary"},
    {"h", "text/plain", "7bit", "text"},
    {"hdf", "application/x-hdf", "binary", "binary"},
    {"hh", "text/plain", "7bit", "text"},
    {"hqx", "application/mac-binhex40", "mac-binhex40", "binary"},
    {"htm", "text/html", "8bit", "text"},
    {"html", "text/html", "8bit", "text"},
    {"ief", "image/ief", "binary", "image"},
    {"jpe", "image/jpeg", "binary", "image"},
    {"jpeg", "image/jpeg", "binary", "image"},
    {"jpg", "image/jpeg", "binary", "image"},
    {"latex", "application/x-latex", "8bit", "text"},
    {"lzh", "application/octet-stream", "binary", "binary"},
    {"m", "text/plain", "7bit", "text"},
    {"man", "application/x-troff-man", "7bit", "text"},
    {"me", "application/x-troff-me", "7bit", "text"},
    {"mif", "application/x-mif", "binary", "binary"},
    {"mime", "www/mime", "8bit", "text"},
    {"mov", "video/quicktime", "binary", "movie"},
    {"movie", "video/x-sgi-movie", "binary", "movie"},
    {"mpe", "video/mpeg", "binary", "movie"},
    {"mpeg", "video/mpeg", "binary", "movie"},
    {"mpg", "video/mpeg", "binary", "movie"},
    {"ms", "application/x-troff-ms", "7bit", "text"},
    {"msw", "application/msword", "binary", "binary"},
    {"mwrt", "application/macwriteii", "binary", "binary"},
    {"nc", "application/x-netcdf", "binary", "binary"},
    {"oda", "application/oda", "binary", "binary"},
    {"pbm", "image/x-portable-bitmap", "binary", "image"},
    {"pdf", "application/pdf", "binary", "binary"},
    {"pgm", "image/x-portable-graymap", "binary", "image"},
    {"pic", "application/pict", "binary", "image"},
    {"pict", "application/pict", "binary", "image"},
    {"pnm", "image/x-portable-anymap", "binary", "image"},
    {"ppm", "image/x-portable-pixmap", "binary", "image"},
    {"ps", "application/postscript", "8bit", "text"},
    {"qt", "video/quicktime", "binary", "movie"},
    {"ras", "image/cmu-raster", "binary", "image"},
    {"rgb", "image/x-rgb", "binary", "image"},
    {"roff", "application/x-troff", "7bit", "text"},
    {"rtf", "application/x-rtf", "7bit", "binary"},
    {"rtx", "text/richtext", "7bit", "text"},
    {"sh", "application/x-sh", "7bit", "text"},
    {"shar", "application/x-shar", "8bit", "text"},
    {"sit", "application/stuffit", "binary", "binary"},
    {"snd", "audio/basic", "binary", "sound"},
    {"src", "application/x-wais-source", "7bit", "text"},
    {"sv4cpio", "application/x-sv4cpio", "binary", "binary"},
    {"sv4crc", "application/x-sv4crc", "binary", "binary"},
    {"t", "application/x-troff", "7bit", "text"},
    {"tar", "application/x-tar", "binary", "binary"},
    {"tcl", "application/x-tcl", "7bit", "text"},
    {"tex", "application/x-tex", "8bit", "text"},
    {"texi", "application/x-texinfo", "7bit", "text"},
    {"texinfo", "application/x-texinfo", "7bit", "text"},
    {"tgz", "application/x-tar", "x-gzip", "binary"},
    {"tif", "image/tiff", "binary", "image"},
    {"tiff", "image/tiff", "binary", "image"},
    {"tr", "application/x-troff", "7bit", "text"},
    {"tsv", "text/tab-separated-values", "7bit", "text"},
    {"txt", "text/plain", "7bit", "text"},
    {"ustar", "application/x-ustar", "binary", "binary"},
    {"wav", "audio/x-wav", "binary", "sound"},
    {"xbm", "image/x-xbitmap", "binary", "image"},
    {"xpm", "image/x-xpixmap", "binary", "image"},
    {"xwd", "image/x-xwindowdump", "binary", "image"},
    {"zip", "application/x-zip-compressed", "zip", "binary"}
};

==> squid-1.0.12-src.tar.gz: squid-1.0.12/include/mime_table.h <==
#define EXT_TABLE_LEN 91
static ext_table_entry ext_mime_table[] =
{
    {"Z", "application/x-compressed", "x-compress", "binary"},
    {"ai", "application/postscript", "8bit", "text"},
    {"aif", "audio/x-aiff", "binary", "sound"},
    {"aifc", "audio/x-aiff", "binary", "sound"},
    {"aiff", "audio/x-aiff", "binary", "sound"},
    {"arj", "application/x-arj-compressed", "binary", "binary"},
    {"au", "audio/basic", "binary", "sound"},
    {"avi", "video/x-msvideo", "binary", "movie"},
    {"bcpio", "application/x-bcpio", "binary", "binary"},
    {"bin", "application/macbinary", "macbinary", "binary"},
    {"c", "text/plain", "7bit", "text"},
    {"cc", "text/plain", "7bit", "text"},
    {"cdf", "application/x-netcdf", "binary", "binary"},
    {"cpio", "application/x-cpio", "binary", "binary"},
    {"csh", "application/x-csh", "7bit", "text"},
    {"doc", "application/msword", "binary", "binary"},
    {"dvi", "application/x-dvi", "binary", "binary"},
    {"eps", "application/postscript", "8bit", "text"},
    {"etx", "text/x-setext", "7bit", "text"},
    {"exe", "application/octet-stream", "binary", "binary"},
    {"f90", "text/plain", "7bit", "text"},
    {"gif", "image/gif", "binary", "image"},
    {"gtar", "application/x-gtar", "binary", "binary"},
    {"gz", "text/plain", "x-gzip", "binary"},
    {"h", "text/plain", "7bit", "text"},
    {"hdf", "application/x-hdf", "binary", "binary"},
    {"hh", "text/plain", "7bit", "text"},
    {"hqx", "application/mac-binhex40", "mac-binhex40", "binary"},
    {"htm", "text/html", "8bit", "text"},
    {"html", "text/html", "8bit", "text"},
    {"ief", "image/ief", "binary", "image"},
    {"jpe", "image/jpeg", "binary", "image"},
    {"jpeg", "image/jpeg", "binary", "image"},
    {"jpg", "image/jpeg", "binary", "image"},
    {"latex", "application/x-latex", "8bit", "text"},
    {"lha", "application/x-lha-compressed", "binary", "binary"},
    {"lzh", "application/x-lha-compressed", "binary", "binary"},
    {"m", "text/plain", "7bit", "text"},
    {"man", "application/x-troff-man", "7bit", "text"},
    {"me", "application/x-troff-me", "7bit", "text"},
    {"mif", "application/x-mif", "binary", "binary"},
    {"mime", "www/mime", "8bit", "text"},
    {"mov", "video/quicktime", "binary", "movie"},
    {"movie", "video/x-sgi-movie", "binary", "movie"},
    {"mpe", "video/mpeg", "binary", "movie"},
    {"mpeg", "video/mpeg", "binary", "movie"},
    {"mpg", "video/mpeg", "binary", "movie"},
    {"ms", "application/x-troff-ms", "7bit", "text"},
    {"msw", "application/msword", "binary", "binary"},
    {"mwrt", "application/macwriteii", "binary", "binary"},
    {"nc", "application/x-netcdf", "binary", "binary"},
    {"oda", "application/oda", "binary", "binary"},
    {"pbm", "image/x-portable-bitmap", "binary", "image"},
    {"pdf", "application/pdf", "binary", "binary"},
    {"pgm", "image/x-portable-graymap", "binary", "image"},
    {"pic", "application/pict", "binary", "image"},
    {"pict", "application/pict", "binary", "image"},
    {"pnm", "image/x-portable-anymap", "binary", "image"},
    {"ppm", "image/x-portable-pixmap", "binary", "image"},
    {"ps", "application/postscript", "8bit", "text"},
    {"qt", "video/quicktime", "binary", "movie"},
    {"ras", "image/cmu-raster", "binary", "image"},
    {"rgb", "image/x-rgb", "binary", "image"},
    {"roff", "application/x-troff", "7bit", "text"},
    {"rtf", "application/x-rtf", "7bit", "binary"},
    {"rtx", "text/richtext", "7bit", "text"},
    {"sh", "application/x-sh", "7bit", "text"},
    {"shar", "application/x-shar", "8bit", "text"},
    {"sit", "application/stuffit", "binary", "binary"},
    {"snd", "audio/basic", "binary", "sound"},
    {"src", "application/x-wais-source", "7bit", "text"},
    {"sv4cpio", "application/x-sv4cpio", "binary", "binary"},
    {"sv4crc", "application/x-sv4crc", "binary", "binary"},
    {"t", "application/x-troff", "7bit", "text"},
    {"tar", "application/x-tar", "binary", "binary"},
    {"tcl", "application/x-tcl", "7bit", "text"},
    {"tex", "application/x-tex", "8bit", "text"},
    {"texi", "application/x-texinfo", "7bit", "text"},
    {"texinfo", "application/x-texinfo", "7bit", "text"},
    {"tgz", "application/x-tar", "x-gzip", "binary"},
    {"tif", "image/tiff", "binary", "image"},
    {"tiff", "image/tiff", "binary", "image"},
    {"tr", "application/x-troff", "7bit", "text"},
    {"tsv", "text/tab-separated-values", "7bit", "text"},
    {"txt", "text/plain", "7bit", "text"},
    {"ustar", "application/x-ustar", "binary", "binary"},
    {"wav", "audio/x-wav", "binary", "sound"},
    {"xbm", "image/x-xbitmap", "binary", "image"},
    {"xpm", "image/x-xpixmap", "binary", "image"},
    {"xwd", "image/x-xwindowdump", "binary", "image"},
    {"zip", "application/x-zip-compressed", "zip", "binary"}
};
